@@ -152,6 +152,9 @@ def main():  # noqa: C901  # pylint: disable=too-many-branches,too-many-statemen
             secrets = netrc.netrc(file=args.netrc)
             secret = secrets.authenticators("volkswagen.de")
             username, _, password = secret
+        except netrc.NetrcParseError as err:
+            LOG.error('Authentification using .netrc failed: %s', err)
+            sys.exit(1)
         except TypeError:
             if not args.username:
                 LOG.error('volkswagen.de entry was not found in %s netrc-file. Create it or provide at least a username'
@@ -257,11 +260,11 @@ def main():  # noqa: C901  # pylint: disable=too-many-branches,too-many-statemen
         mqttCLient.weConnect.persistTokens()
     except KeyboardInterrupt:
         pass
-    except weconnect.AuthentificationError as e:
+    except errors.AuthentificationError as e:
         errorMessage = f'There was a problem when authenticating with WeConnect: {e}'
         mqttCLient.setError(code=WeConnectErrors.AUTHENTIFICATION, message=errorMessage)
         LOG.critical(errorMessage)
-    except weconnect.APICompatibilityError as e:
+    except errors.APICompatibilityError as e:
         errorMessage = f'There was a problem when communicating with WeConnect.  If this problem persists please open a bug report: {e}'
         mqttCLient.setError(code=WeConnectErrors.API_COMPATIBILITY, message=errorMessage)
         LOG.critical(errorMessage)
@@ -499,6 +502,8 @@ class WeConnectMQTTClient(paho.mqtt.client.Client):  # pylint: disable=too-many-
                     LOG.error('Could not reconnect to MQTT-Server: %s, will retry in 10 seconds', e)
                 except socket.timeout:
                     LOG.error('Could not reconnect to MQTT-Server due to timeout, will retry in 10 seconds')
+                except OSError as e:
+                    LOG.error('Could not reconnect to MQTT-Server: %s, will retry in 10 seconds', e)
                 finally:
                     time.sleep(10)
 
